@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -130,8 +130,7 @@ public class MyService extends Service {
 
     notificationManager.notify(1, notification);
 
-    if (Build.VERSION.SDK_INT >= 5)
-      APILevel5.startForeground(this, 1, notification);
+    startForeground(1, notification);
   }
 
   @Override public void onStart(Intent intent, int startId) {
