@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,15 +24,15 @@ Copyright_License {
 #include "NativeLeScanCallback.hpp"
 #include "LeScanCallback.hpp"
 #include "Main.hpp"
-#include "Java/Class.hxx"
-#include "Java/String.hxx"
+#include "java/Class.hxx"
+#include "java/String.hxx"
 #include "org_xcsoar_NativeLeScanCallback.h"
 
 namespace NativeLeScanCallback {
-  static Java::TrivialClass cls;
-  static jmethodID ctor;
-  static jfieldID ptr_field;
-};
+static Java::TrivialClass cls;
+static jmethodID ctor;
+static jfieldID ptr_field;
+} // namespace NativeLeScanCallback
 
 JNIEXPORT void JNICALL
 Java_org_xcsoar_NativeLeScanCallback_onLeScan(JNIEnv *env, jobject obj,
@@ -59,8 +59,7 @@ Java_org_xcsoar_NativeLeScanCallback_onLeScan(JNIEnv *env, jobject obj,
 void
 NativeLeScanCallback::Initialise(JNIEnv *env)
 {
-  if (android_api_level < 18 ||
-      !cls.FindOptional(env, "org/xcsoar/NativeLeScanCallback"))
+  if (!cls.FindOptional(env, "org/xcsoar/NativeLeScanCallback"))
     /* Bluetooth LE not supported on this Android version */
     return;
 
