@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,19 +24,20 @@ Copyright_License {
 #ifndef XCSOAR_ANDROID_NATIVE_VIEW_HPP
 #define XCSOAR_ANDROID_NATIVE_VIEW_HPP
 
-#include "Java/Object.hxx"
-#include "Java/Class.hxx"
-#include "Java/String.hxx"
+#include "java/Object.hxx"
+#include "java/Class.hxx"
+#include "java/String.hxx"
+#include "system/Path.hpp"
 
 #ifndef NO_SCREEN
-#include "Screen/Point.hpp"
+#include "ui/dim/Size.hpp"
 #endif
 
-#include <assert.h>
+#include <cassert>
 
 class NativeView {
   JNIEnv *env;
-  Java::Object obj;
+  Java::GlobalObject obj;
 
   unsigned width, height;
   char product[20];
@@ -45,13 +46,17 @@ class NativeView {
   static jfieldID textureNonPowerOfTwo_field;
   static jmethodID init_surface_method, deinit_surface_method;
   static jmethodID setRequestedOrientationID;
-  static jmethodID swap_method;
   static jmethodID loadResourceBitmap_method;
   static jmethodID loadFileBitmap_method;
   static jmethodID bitmapToTexture_method;
   static jmethodID open_file_method;
   static jmethodID getNetState_method;
 
+  static Java::TrivialClass clsBitmap;
+  static jmethodID createBitmap_method;
+
+  static Java::TrivialClass clsBitmapConfig;
+  static jmethodID bitmapConfigValueOf_method;
 public:
   /**
    * @see http://developer.android.com/reference/android/R.attr.html#screenOrientation
@@ -69,9 +74,6 @@ public:
     // see http://developer.android.com/reference/android/content/pm/ActivityInfo.html#SCREEN_ORIENTATION_REVERSE_LANDSCAPE
     REVERSE_LANDSCAPE = 8,
     REVERSE_PORTRAIT = 9,
-    // HACK for Galaxy Tab (FROYO = 2.2 = API level 8)
-    REVERSE_LANDSCAPE_GT = 7,
-    REVERSE_PORTRAIT_GT = 8,
   };
 
   static void Initialise(JNIEnv *env);
@@ -81,9 +83,6 @@ public:
              unsigned _xdpi, unsigned _ydpi,
              jstring _product) noexcept;
 
-  unsigned GetWidth() const { return width; }
-  unsigned GetHeight() const { return height; }
-
 #ifndef NO_SCREEN
   PixelSize GetSize() const {
     return { width, height };
@@ -111,19 +110,14 @@ public:
     return env->CallBooleanMethod(obj, setRequestedOrientationID, (jint)so);
   }
 
-  void swap() {
-    env->CallVoidMethod(obj, swap_method);
-  }
-
   jobject loadResourceBitmap(const char *name) {
     Java::String name2(env, name);
     return env->CallObjectMethod(obj, loadResourceBitmap_method, name2.Get());
   }
 
-  jobject loadFileBitmap(const char *path) {
-    Java::String path2(env, path);
-    return env->CallObjectMethod(obj, loadFileBitmap_method, path2.Get());
-  }
+  jobject loadFileTiff(Path path);
+
+  jobject loadFileBitmap(Path path);
 
   bool bitmapToTexture(jobject bmp, bool alpha, jint *result) {
     jintArray result2 = env->NewIntArray(5);
