@@ -553,6 +553,8 @@ DeviceDescriptor::Open(OperationEnvironment &env)
 
   open_job = new OpenDeviceJob(*this);
   async.Start(open_job, env, &job_finished_notify);
+
+  PortStateChanged();
 }
 
 void
@@ -920,6 +922,22 @@ DeviceDescriptor::PutVolume(unsigned volume, OperationEnvironment &env)
   return device->PutVolume(volume, env);
 }
 
+bool
+DeviceDescriptor::PutPilotEvent(OperationEnvironment &env)
+{
+  assert(InMainThread());
+
+  if (device == nullptr || !config.sync_to_device)
+    return true;
+
+  if (!Borrow())
+    /* TODO: postpone until the borrowed device has been returned */
+    return false;
+
+  ScopeReturnDevice restore(*this, env);
+  return device->PutPilotEvent(env);
+}
+
 bool
 DeviceDescriptor::PutActiveFrequency(RadioFrequency frequency,
                                      const TCHAR *name,
@@ -1186,6 +1204,8 @@ DeviceDescriptor::OnJobFinished() noexcept
 
   delete open_job;
   open_job = nullptr;
+
+  PortStateChanged();
 }
 
 void
