@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,12 +26,12 @@
 
 #include <algorithm>
 
-#include <assert.h>
+#include <cassert>
 
 GlideState
 GlideState::Remaining(const TaskPoint &tp,
                       const AircraftState &aircraft,
-                      const fixed min_h)
+                      const double min_h)
 {
   assert(aircraft.location.IsValid());
 
