@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -23,9 +23,10 @@ Copyright_License {
 
 #include "Trace.hpp"
 #include "Vector.hpp"
-#include "Util/GlobalSliceAllocator.hxx"
+#include "util/GlobalSliceAllocator.hxx"
 
 #include <algorithm>
+#include <iterator>
 
 Trace::Trace(const unsigned _no_thin_time, const unsigned max_time,
              const unsigned max_size)
@@ -428,7 +429,7 @@ Trace::SyncPoints(TracePointerVector &v) const
 
 void
 Trace::GetPoints(TracePointVector &v, unsigned min_time,
-                 const GeoPoint &location, fixed min_distance) const
+                 const GeoPoint &location, double min_distance) const
 {
   /* skip the trace points that are before min_time */
   Trace::const_iterator i = begin(), end = this->end();
