@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@ Waypoint::Waypoint(const GeoPoint &_location)
 }
 
 bool
-Waypoint::IsCloseTo(const GeoPoint &_location, const fixed range) const
+Waypoint::IsCloseTo(const GeoPoint &_location, const double range) const
 {
   return location.Distance(_location) <= range;
 }
