@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,26 +25,22 @@ Copyright_License {
 #define XCSOAR_INFO_BOX_HPP
 
 #include "InfoBoxes/Content/Base.hpp"
-#include "Screen/LazyPaintWindow.hpp"
-#include "Screen/Timer.hpp"
+#include "ui/window/LazyPaintWindow.hpp"
+#include "ui/event/Timer.hpp"
 #include "Data.hpp"
 
+#include <memory>
+
 struct InfoBoxSettings;
 struct InfoBoxLook;
-struct UnitsLook;
 class Color;
 
 class InfoBoxWindow : public LazyPaintWindow
 {
-  /** timeout of infobox focus [ms] */
-  static constexpr unsigned FOCUS_TIMEOUT_MAX = 20 * 1000;
-
-private:
-  InfoBoxContent *content;
+  std::unique_ptr<InfoBoxContent> content;
 
   const InfoBoxSettings &settings;
   const InfoBoxLook &look;
-  const UnitsLook &units_look;
 
   const unsigned border_kind;
 
@@ -52,33 +48,35 @@ private:
 
   InfoBoxData data;
 
-  bool dragging;
+  bool dragging = false;
 
   /**
    * Is the mouse currently pressed inside this InfoBox?
    */
-  bool pressed;
+  bool pressed = false;
 
   /**
    * draw the selector event if the InfoBox window is not the system focus
    */
-  bool force_draw_selector;
+  bool force_draw_selector = false;
 
   /** a timer which returns keyboard focus back to the map window after a while */
-  WindowTimer focus_timer;
+  UI::Timer focus_timer{[this]{ FocusParent(); }};
 
   /**
    * This timer opens the dialog.  It is used to check for "long
    * click" and to delay the dialog a bit (for double click
    * detection).
    */
-  WindowTimer dialog_timer;
+  UI::Timer dialog_timer{[this]{ OnDialogTimer(); }};
 
   PixelRect title_rect;
   PixelRect value_rect;
   PixelRect comment_rect;
   PixelRect value_and_comment_rect;
 
+  unsigned unit_width = 0;
+
   /**
    * Paints the InfoBox title to the given canvas
    * @param canvas The canvas to paint on
@@ -100,8 +98,8 @@ private:
   void Paint(Canvas &canvas);
 
 public:
-  void PaintInto(Canvas &dest, PixelScalar xoff, PixelScalar yoff,
-                 UPixelScalar width, UPixelScalar height);
+  void PaintInto(Canvas &dest, int xoff, int yoff,
+                 unsigned width, unsigned height);
 
   /**
    * Sets the InfoBox title to the given Value
@@ -119,17 +117,14 @@ public:
    */
   InfoBoxWindow(ContainerWindow &parent, PixelRect rc, unsigned border_flags,
                 const InfoBoxSettings &settings, const InfoBoxLook &_look,
-                const UnitsLook &units_look,
                 unsigned id,
                 WindowStyle style=WindowStyle());
 
-  ~InfoBoxWindow();
-
   const InfoBoxLook &GetLook() const {
     return look;
   }
 
-  void SetContentProvider(InfoBoxContent *_content);
+  void SetContentProvider(std::unique_ptr<InfoBoxContent> _content);
   void UpdateContent();
 
 private:
@@ -157,21 +152,22 @@ public:
     return value_and_comment_rect;
   }
 
+private:
+  void OnDialogTimer() noexcept;
+
 protected:
   virtual void OnDestroy() override;
   virtual void OnResize(PixelSize new_size) override;
   virtual void OnSetFocus() override;
   virtual void OnKillFocus() override;
   virtual void OnCancelMode() override;
-  virtual bool OnTimer(WindowTimer &timer) override;
 
   virtual bool OnKeyDown(unsigned key_code) override;
 
-  virtual bool OnMouseDown(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseUp(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseDouble(PixelScalar x, PixelScalar y) override;
-  virtual bool OnMouseMove(PixelScalar x, PixelScalar y,
-                           unsigned keys) override;
+  bool OnMouseDown(PixelPoint p) override;
+  bool OnMouseUp(PixelPoint p) override;
+  bool OnMouseDouble(PixelPoint p) override;
+  bool OnMouseMove(PixelPoint p, unsigned keys) override;
 
   /* virtual methods from class LazyPaintWindow */
   void OnPaintBuffer(Canvas &canvas) override;
