@@ -128,8 +128,6 @@ NMEAInfo::Reset()
   track = Angle::Zero();
   track_available.Clear();
 
-  heading_available.Clear();
-
   variation_available.Clear();
 
   ground_speed_available.Clear();
@@ -337,11 +335,6 @@ NMEAInfo::Complement(const NMEAInfo &add)
     temperature_available = add.temperature_available;
   }
 
-  if (!heading_available && add.heading_available) {
-    heading = add.heading;
-    heading_available = add.heading_available;
-  }
-
    if (!variation_available && add.variation_available) {
     variation = add.variation;
     variation_available = add.variation_available;
