@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@
 #ifndef TASK_AUTOPILOT_HPP
 #define TASK_AUTOPILOT_HPP
 
-#include "Math/fixed.hpp"
 #include "Math/Angle.hpp"
 #include "Math/Filter.hpp"
 #include "Geo/GeoPoint.hpp"
@@ -30,12 +29,12 @@
 struct AircraftState;
 
 struct AutopilotParameters {
-  fixed bearing_noise;
-  fixed target_noise;
-  fixed turn_speed;
-  fixed sink_factor;
-  fixed climb_factor;
-  fixed start_alt;
+  double bearing_noise;
+  double target_noise;
+  double turn_speed;
+  double sink_factor;
+  double climb_factor;
+  double start_alt;
   bool enable_bestcruisetrack;
   bool goto_target;
 
@@ -89,8 +88,8 @@ protected:
 private:
   const AutopilotParameters &parms;
   Filter heading_filter;
-  fixed climb_rate;
-  fixed speed_factor;
+  double climb_rate;
+  double speed_factor;
   GeoPoint w[2];
 
 public:
@@ -101,15 +100,15 @@ public:
                           const AircraftState& state);
 
   virtual void UpdateState(const TaskAccessor& task,
-                           AircraftState& state, const fixed timestep=fixed(1));
+                           AircraftState &state, double timestep=1);
 
   bool UpdateAutopilot(TaskAccessor &task,
                        const AircraftState &state);
 
-  gcc_pure
+  [[gnu::pure]]
   GeoPoint GetTarget(const TaskAccessor& task) const;
 
-  void SetSpeedFactor(fixed f) {
+  void SetSpeedFactor(double f) {
     speed_factor = f;
   }
 
@@ -117,21 +116,21 @@ private:
   bool DoAdvance(TaskAccessor& task);
   void AdvanceIfRequired(TaskAccessor& task);
 
-  gcc_pure
+  [[gnu::pure]]
   bool HasFinished(const TaskAccessor &task) const;
 
   void GetAWP(const TaskAccessor &task);
 
-  gcc_pure
+  [[gnu::pure]]
   bool HasTarget(const TaskAccessor& task) const;
 
   virtual GeoPoint GetStartLocation(const TaskAccessor& task,
                                     bool previous = false);
 
   void UpdateCruiseBearing(const TaskAccessor& task, const AircraftState& state,
-                           const fixed timestep);
+                           double timestep);
 
-  fixed GetTargetHeight(const TaskAccessor& task) const;
+  double GetTargetHeight(const TaskAccessor &task) const;
   Angle GetHeadingDeviation();
   bool UpdateComputer(TaskAccessor &task, const AircraftState& state);
   bool IsFarFromTarget(const TaskAccessor& task,
