@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@ Copyright_License {
 
 #include <type_traits>
 
-#include <stdint.h>
+#include <cstdint>
 
 /**
  * User interface settings.
@@ -47,12 +47,19 @@ struct UISettings {
   /** timeout in quarter seconds of menu button */
   unsigned menu_timeout;
 
-#ifndef GNAV
   unsigned scale;
-#endif
 
-  /** Show ThermalAssistant if circling */
-  bool enable_thermal_assistant_gauge;
+  /** Override OS dpi settings */
+  unsigned custom_dpi;
+
+  /** Position ThermalAssistant */
+  enum class ThermalAssistantPosition: uint8_t {
+    OFF,
+    BOTTOM_LEFT,
+    BOTTOM_LEFT_AVOID_IB,
+    BOTTOM_RIGHT,
+    BOTTOM_RIGHT_AVOID_IB,
+  } thermal_assistant_position;
 
   /** Enable warning dialog */
   bool enable_airspace_warning_dialog;
@@ -84,11 +91,7 @@ struct UISettings {
   void SetDefaults();
 
   unsigned GetPercentScale() const {
-#ifndef GNAV
     return scale;
-#endif
-
-    return 100;
   }
 };
 
