@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@ Copyright_License {
 #ifndef XCSOAR_UNITS_UNIT_HPP
 #define XCSOAR_UNITS_UNIT_HPP
 
-#include <stdint.h>
+#include <cstdint>
 
 enum class Unit: uint8_t {
   UNDEFINED,
@@ -50,7 +50,9 @@ enum class Unit: uint8_t {
   LB_PER_FT2,
   KG,
   LB,
-
+  PERCENT,
+  GRADIENT,
+  VOLT,
   /**
    * The sentinel: the number of units in this enum.
    */
