@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -27,11 +27,11 @@ Copyright_License {
 #include "WaypointReaderBase.hpp"
 
 class WaypointReaderCompeGPS final : public WaypointReaderBase {
-  bool is_utm;
+  bool is_utm = false;
 
 public:
   explicit WaypointReaderCompeGPS(WaypointFactory _factory)
-    :WaypointReaderBase(_factory), is_utm(false) {}
+    :WaypointReaderBase(_factory) {}
 
   static bool VerifyFormat(TLineReader &reader);
 
