@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,7 +22,8 @@
 
 #include "Profile/Profile.hpp"
 #include "LocalPath.hpp"
-#include "OS/Args.hpp"
+#include "system/Args.hpp"
+#include "system/Path.hpp"
 
 #include <stdio.h>
 
@@ -32,7 +33,7 @@ int main(int argc, char **argv) {
   args.ExpectEnd();
 
   InitialiseDataPath();
-  Profile::SetFiles(_T(""));
+  Profile::SetFiles(nullptr);
   Profile::Load();
   DeinitialiseDataPath();
 
