@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,36 +26,30 @@ Copyright_License {
 #include "Device/Port/ConfiguredPort.hpp"
 #include "Device/Driver/Vega/Internal.hpp"
 #include "Device/Config.hpp"
-#include "OS/Args.hpp"
+#include "system/Args.hpp"
 #include "Operation/ConsoleOperationEnvironment.hpp"
-#include "IO/Async/GlobalIOThread.hpp"
+#include "io/async/GlobalAsioThread.hpp"
+#include "io/async/AsioThread.hpp"
+#include "io/NullDataHandler.hpp"
+#include "util/PrintException.hxx"
 
 #include <stdio.h>
 #include <string.h>
 
-#ifdef __clang__
-/* true, the nullptr cast below is a bad kludge */
-#pragma GCC diagnostic ignored "-Wnull-dereference"
-#endif
-
-int main(int argc, char **argv)
-{
+int
+main(int argc, char **argv)
+try {
   Args args(argc, argv, "PORT BAUD [NAME=VALUE] [NAME] ...");
-  const DeviceConfig config = ParsePortArgs(args);
+  DebugPort debug_port(args);
 
-  InitialiseIOThread();
+  ScopeGlobalAsioThread global_asio_thread;
 
-  Port *port = OpenPort(config, nullptr, *(DataHandler *)nullptr);
-  if (port == NULL) {
-    fprintf(stderr, "Failed to open COM port\n");
-    return EXIT_FAILURE;
-  }
+  NullDataHandler handler;
+  auto port = debug_port.Open(*asio_thread, *global_cares_channel, handler);
 
   ConsoleOperationEnvironment env;
 
   if (!port->WaitConnected(env)) {
-    delete port;
-    DeinitialiseIOThread();
     fprintf(stderr, "Failed to connect the port\n");
     return EXIT_FAILURE;
   }
@@ -78,7 +72,8 @@ int main(int argc, char **argv)
     free(q);
   }
 
-  delete port;
-  DeinitialiseIOThread();
   return EXIT_SUCCESS;
+} catch (const std::exception &exception) {
+  PrintException(exception);
+  return EXIT_FAILURE;
 }
